@@ -2,7 +2,8 @@
 
 // pub use sailfish::TemplateOnce;
 
-mod startup;
+pub mod startup;
 pub use startup::*;
+pub mod event;
 
 // EOF
