@@ -13,9 +13,10 @@ pub struct OptsCommon {
 }
 impl OptsCommon {
     pub fn finish(&mut self) -> anyhow::Result<()> {
+        // do sanity checking or env var expansion etc...
         Ok(())
     }
-    fn get_loglevel(&self) -> LevelFilter {
+    pub fn get_loglevel(&self) -> LevelFilter {
         if self.trace {
             LevelFilter::Trace
         } else if self.debug {
@@ -33,10 +34,10 @@ pub struct OptsConsoleServer {
     #[structopt(short, long, default_value = "127.0.0.1:24242")]
     pub listen: String,
     #[structopt(short, long, default_value = "/dev/ttyUSB0")]
-    pub serial_port: String,
+    pub ser_port: String,
     #[structopt(long, default_value = "none")]
     pub ser_flow: String,
-    #[structopt(short = "b", long, default_value = "9600")]
+    #[structopt(short = "b", long, default_value = "115200")]
     pub ser_baud: u32,
     #[structopt(long, default_value = "8")]
     pub ser_datab: u32,
@@ -68,15 +69,9 @@ impl OptsConsoleWeb {
     }
 }
 
-pub fn expand_home(pathname: &mut String) -> anyhow::Result<()> {
-    let home = env::var("HOME")?;
-    *pathname = pathname.as_str().replace("$HOME", &home);
-    Ok(())
-}
-
-pub fn start_pgm(c: &OptsCommon, desc: &str) {
+pub fn start_pgm(opts: &OptsCommon, desc: &str) {
     env_logger::Builder::new()
-        .filter_level(c.get_loglevel())
+        .filter_level(opts.get_loglevel())
         .format_timestamp_secs()
         .init();
     info!("Starting up {}...", desc);
@@ -85,5 +80,4 @@ pub fn start_pgm(c: &OptsCommon, desc: &str) {
     debug!("Source timestamp: {}", env!("SOURCE_TIMESTAMP"));
     debug!("Compiler version: {}", env!("RUSTC_VERSION"));
 }
-
 // EOF
